/*
    A script to add a specified extra thickness (extra_t) around the top of the rod hole
    in the Prusa MK4 y-rod holder
    
    CJH, March 2024
*/

$fa = 1;//1 minimum angle for a fragment
$fs = 0.1;//0.1 minimum size of a fragment

extra_t = 0.825;    // extra thickness of top.  This seems sufficient, and still leaves
                    // ~1mm clearance to underside of carriage  
t = 0.375+extra_t;  // 0.375 = original thickness of top, after existing chamfer
chamfer = 0.2;      // chamfer to apply to thicker top - matches chamfer on clamp part
ht = 10;            // height of y-rod holder
hole_rad = 4.5;     // radius of hole to top of chamfer - rod is 8mm diam, chamfer is 0.5mm

// make the complete part
import("y-rod-holder-R2.stl");
thicker_top();

//draw original for comparison images
//translate([0,20,0]) import("y-rod-holder-R2.stl");


module thicker_top(){// make an extruded segment to thicken the top above the rod hole
    translate([1.77,-3.81]) color("red") rotate_extrude(angle=-135) 
    polygon([
        [hole_rad,0],
        [hole_rad+t-chamfer,0],
        [hole_rad+t,chamfer],
        [hole_rad+t,ht-chamfer],
        [hole_rad+t-chamfer,ht],
        [hole_rad,ht]
    ]);
}    